
# Type: base


python base type that implements this type definition

URI: [meta:base](https://w3id.org/biolink/biolinkml/meta/base)


## Domain and Range

[TypeDefinition](TypeDefinition.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [TypeDefinition](TypeDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | every root type must have a base |
|  | | the base is inherited by child types but may be overriden.  Base compatibility is not checked. |

